bayespy.inference.vmp.nodes.categorical_markov_chain.CategoricalMarkovChainDistribution
=======================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical_markov_chain

.. autoclass:: CategoricalMarkovChainDistribution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~CategoricalMarkovChainDistribution.__init__
      ~CategoricalMarkovChainDistribution.compute_cgf_from_parents
      ~CategoricalMarkovChainDistribution.compute_fixed_moments_and_f
      ~CategoricalMarkovChainDistribution.compute_gradient
      ~CategoricalMarkovChainDistribution.compute_logpdf
      ~CategoricalMarkovChainDistribution.compute_message_to_parent
      ~CategoricalMarkovChainDistribution.compute_moments_and_cgf
      ~CategoricalMarkovChainDistribution.compute_phi_from_parents
      ~CategoricalMarkovChainDistribution.compute_weights_to_parent
      ~CategoricalMarkovChainDistribution.plates_from_parent
      ~CategoricalMarkovChainDistribution.plates_to_parent
      ~CategoricalMarkovChainDistribution.random
   
   

   
   
   